#!/usr/bin/env python
# -*- coding:utf-8
import requests
from . import data

username=""
password=""

#----baidu文字识别配置
'''words默认主目录设置'''
_words_path = "E:\\pool\\"

#----baidu图像识别配置
'''image默认主目录设置'''
_image_path = "E:\\pool\\"

#----baidu语音识别配置
'''speech默认主目录设置'''
_speech_path = "E:\\pool\\"

#----files文件操作配置
'''files默认主目录设置'''
_files_path = "E:\\pool\\"

#----API 鉴权
def AccessToken(_Com,_Class,_API_Key, _Secret_Key):
    def Run(_Com,_Class):
        '''请勿手动修改redis的access_token数据，否则有可能导致程序失效'''
        if data.Get( str( _Com ) + '_' + str( _Class ) + '_access_token' ):
            data.Close()
            return 0
        else:
            _host = 'https://aip.baidubce.com/oauth/2.0/token?grant_type=client_credentials&client_id=' + _API_Key + '&client_secret=' + _Secret_Key
            response = requests.get( _host )
            if response:
                _value = response.json()['access_token']
                data.Set( str( _Com ) + '_' + str( _Class ) + '_access_token', _value, ex=3600 * 24 * 29 )
                data.Close()
                return 1

    '''
    _Com参数：
        0 代表百度API

    _Class参数:
        0 代表文字识别access_token
        1 代表图像识别access_token
        2 代表EasyDL定制化模型access_token
        3 代表语音识别

    返回值：
        1 代表access_token生成成功
        0 代表access_token生成失败
    '''
    if _Com==0 and _Class == 0:
        return Run( _Com, _Class )
    if _Com==0 and _Class == 1:
        return Run( _Com, _Class )
    if _Com==0 and _Class == 2:
        return Run( _Com, _Class )
    if _Com==0 and _Class == 3:
        return Run( _Com, _Class )


#!/usr/bin/env python
# -*- coding:utf-8
from .libs import extend,ai,common
_extend=extend.Extend()
_ai=ai.Ai()
_common=common

def Ocr(image,e="low"):
    return _ai.Ocr(image,e)

def OcrFindWords(image, cn, f=0, e="high"):
    return _extend.OcrFindWords(image,cn,f,e)

def OcrCaptureFindWords(x1,y1,x2,y2,fileName,words,f=0,e="high",t=0):
    return _extend.OcrCaptureFindWords(x1,y1,x2,y2,fileName,words,f,e,t)

def FindStr(find_str,all_str,f=0):
    return _common.FindStr(find_str,all_str,f)

def FindCnStr(find_str,all_str):
    return _common.FindCnStr(find_str,all_str)


#!/usr/bin/env python
# -*- coding:utf-8
import redis as pyredis

class PyRedis():
    def __init__(self):
        self._redis = pyredis.StrictRedis( 'localhost', 6379, charset="utf-8", decode_responses=True )
    #录入数据
    def Set(self,name, value,ex=None, px=None, nx=False, xx=False, keepttl=False):
        self._redis.set( name, value,ex, px, nx, xx, keepttl )

    #读取数据
    def Get(self,name):
        return self._redis.get(name)

    #删除数据
    def Delete(self,name):
        return self._redis.delete(name)

    #关闭redis
    def Close(self):
        self._redis.close()

    def Client(self):
        self._redis.client()



#!/usr/bin/env python
# -*- coding:utf-8
import sys
if int( sys.version[0] ) == 3:
    import tkinter as tk
elif int( sys.version[0] ) == 2:
    import Tkinter as tk

class Tkinter():
    #----创建容器
    def TkinterDiv(self):
        return tk.Tk()

    #----显示容器
    def TkinterShowDiv(self,div):
        div.mainloop()

    #----按钮
    def TkinterButton(self,_div,text,color1=None,color2=None,command=None,width=None,height=None,place=1):
        button=tk.Button(master=_div,text=text, bg=color1,activebackground=color2,command=command,width=width,height=height)
        if place==1:
            button.pack()
        elif place==2:
            button.grid()

    #----标签
    def TkinterLabel(self,_div,text,color=None,width=None,height=None,place=1):
        button=tk.Label(master=_div,text=text, bg=color,width=width,height=height)
        if place==1:
            button.pack()
        elif place==2:
            button.grid()




#!/usr/bin/env python
# -*- coding:utf-8
import re
from . import common,ai

class Extend():
    def __init__(self):
        self._common=common
        self._ai=ai

    # ----Ocr查字（支持中文、英文、数字）
    def OcrFindWords(self, image, cn, f=0, e="high"):
        '''
        python2.7版本中，被查找的字符前必须加u ，例如：Orc_FindCnStr("1.bmp",u'摘要',f=0),f=1代表不区分大小写,
        返回1代表查找成功，返回0代表查找失败，e="low"代表普通版，e="high"代表高精版
        '''
        all_str = self._ai.Ai().Ocr( image, e ).encode( 'unicode-escape' ).decode( 'unicode_escape' )
        find_str = cn.encode( 'unicode-escape' ).decode( 'unicode_escape' )
        if f == 1:
            if re.search( find_str, all_str, flags=re.I | re.M ) == None:
                return 0
            else:
                return 1

        else:
            if re.search( find_str, all_str ) == None:
                return 0
            else:
                return 1

    # ----Ocr抓图识别查字（支持中文、英文、数字）
    def OcrCaptureFindWords(self,x1,y1,x2,y2,fileName,words,f=0,e="high",t=0):
        '''
        参数
        x1,x1：左上角坐标
        x2,y2：右下角坐标
        fileName：抓图保存图片名
        words：要查找的字
        f：对大小写是否敏感 ，1 不敏感，0 敏感
        e：识别的精度，low 普通精度，high 高精度
        t：开始抓图延时

        返回值
        1：找到字
        0：未找到字
        '''

        self._common.CommonWordsCapture( x1, y1, x2, y2, fileName,t)
        return self.OcrFindWords(fileName, words,f,e )

    #----遍历并打开指定目录下的所有文件
    def FindOpenFiles(self,files_dir):
        files_name = common.FindFiles( files_dir )
        for i in files_name:
            common.OpenFiles( files_dir + "/" + i )



#!/usr/bin/ python
#coding:utf-8

"""
软件名称:星门数据库(stargateDB)
描述：星门数据库是一款微型电脑数据库
官方首页：http://www.stargatedb.com/
文档教程：http://www.stargatedb.com/index.php/wendangjiaocheng.html
申请账号：http://www.stargatedb.com/index.php/page/user.html
作者：重庆羊排信息技术有限公司
发布日期：2021年4月1日
"""

import requests
import os

#---中英文字符存储
def Add(username,password,key,value,database,life_time=0):
    request_url = "http://api.stargatedb.com:8002/add?username="+username+"&password="+password+"&key=" + str(key)+"&value="+str(value)+"&database="+str(database)+"&life_time="+str(life_time)
    headers = {'content-type': 'application/x-www-form-urlencoded'}
    response = requests.post( request_url,headers=headers)
    result_str = response.text
    return eval(result_str)

def Delete(username,password,key,database):
    request_url = "http://api.stargatedb.com:8002/delete?username="+username+"&password="+password+"&key=" + str( key ) + "&database=" + str(database)
    headers = {'content-type': 'application/x-www-form-urlencoded'}
    response = requests.post( request_url, headers=headers )
    result_str = response.text
    return eval(result_str)

def Change(username,password,key,value,database,life_time=-1):
    request_url = "http://api.stargatedb.com:8002/change?username="+username+"&password="+password+"&key=" + str(key)+"&value="+str(value)+"&database="+str(database)+"&life_time="+str(life_time)
    headers = {'content-type': 'application/x-www-form-urlencoded'}
    response = requests.post( request_url, headers=headers )
    result_str = response.text
    try:
        result=eval(result_str)
        return result
    except:
        return result_str

def Find(username,password,key,database):
    request_url = "http://api.stargatedb.com:8002/find?username="+username+"&password="+password+"&key="+ str(key) +"&database=" + str(database)
    headers = {'content-type': 'application/x-www-form-urlencoded'}
    response = requests.post( request_url, headers=headers )
    result_str = response.text
    try:
        result=eval(result_str)
        return result
    except:
        return result_str

def AllFind(username,password,database):
    request_url = "http://api.stargatedb.com:8002/allfind?username="+username+"&password="+password+"&database=" + str(database)
    headers = {'content-type': 'application/x-www-form-urlencoded'}
    response = requests.post( request_url, headers=headers )
    result_str = response.text
    return eval(result_str)

#---图片存储
"""
图片类型
• jpg  –  image/jpeg 
• png  –  image/png 
• gif  –  image/gif 
• webp  –  image/webp 
• cr2  –  image/x-canon-cr2 
• tif  –  image/tiff 
• bmp  –  image/bmp 
• jxr  –  image/vnd.ms-photo 
• psd  –  image/vnd.adobe.photoshop 
• ico  –  image/x-icon
"""
def AddImage(username,password,image,database,dir_path):
    img_src= dir_path+image
    try:
        files = {'file': (image, open( img_src, 'rb' ), {'Expires': '0'})}
    except:
        return {"state":404,"message":"no find image"}
    request_url = "http://api.stargatedb.com:8002/addimage?username="+username+"&password="+password+"&database=" + str(database)
    response = requests.post( request_url,files = files)
    result_str = response.text
    return eval(result_str)

def DeleteImage(username,password,image,database):
    request_url = "http://api.stargatedb.com:8002/deleteimage?username="+username+"&password="+password+"&image=" + str( image ) + "&database=" + str(database)
    headers = {'content-type': 'application/x-www-form-urlencoded'}
    response = requests.post( request_url, headers=headers )
    result_str = response.text
    return eval(result_str)

def FindImage(username,password,image,database,save_dir):
    request_url = "http://api.stargatedb.com:8002/findimage?username="+username+"&password="+password+"&database=" + str( database ) + "&image=" + str( image )
    headers = {'content-type': 'application/x-www-form-urlencoded'}
    response = requests.post( request_url, headers=headers )
    result_str = response.text
    if not os.path.exists( save_dir ):
        os.mkdir( save_dir )
    img_path=save_dir+"/"+image
    try:
        result_str=eval( result_str )
        if result_str['state'] == 415:
            return {"state": 415, "message": "Unsupported image type"}
        if result_str['state']==404:
            return result_str
    except:
        with open(img_path,'wb') as f:
            f.write(response.content)
        return {"state":200,"message":"find image success"}

#----音频存储
"""
音频类型
• mid  –  audio/midi 
• mp3  –  audio/mpeg 
• m4a  –  audio/m4a 
• ogg  –  audio/ogg 
• flac  –  audio/x-flac 
• wav  –  audio/x-wav
• amr  –  audio/amr
"""
def AddAudio(username,password,audio,database,dir_path):
    audio_src= dir_path+audio
    try:
        files = {'file': (audio, open( audio_src, 'rb' ), {'Expires': '0'})}
    except:
        return {"state":404,"message":"no find audio"}
    request_url = "http://api.stargatedb.com:8002/addaudio?username="+username+"&password="+password+"&database=" + str(database)
    response = requests.post( request_url,files = files)
    result_str = response.text
    return eval(result_str)

def DeleteAudio(username,password,audio,database):
    request_url = "http://api.stargatedb.com:8002/deleteaudio?username="+username+"&password="+password+"&audio=" + str( audio ) + "&database=" + str(database)
    headers = {'content-type': 'application/x-www-form-urlencoded'}
    response = requests.post( request_url, headers=headers )
    result_str = response.text
    return eval(result_str)

def FindAudio(username,password,audio,database,save_dir):
    request_url = "http://api.stargatedb.com:8002/findaudio?username="+username+"&password="+password+"&database=" + str( database ) + "&audio=" + str( audio )
    headers = {'content-type': 'application/x-www-form-urlencoded'}
    response = requests.post( request_url, headers=headers )
    result_str = response.text
    if not os.path.exists( save_dir ):
        os.mkdir( save_dir )
    audio_path=save_dir+"/"+audio
    try:
        result_str=eval( result_str )
        if result_str['state'] == 415:
            return {"state": 415, "message": "Unsupported audio type"}
        if result_str['state']==404:
            return result_str
    except:
        with open(audio_path,'wb') as f:
            f.write(response.content)
        return {"state":200,"message":"find audio success"}

#----视频存储
"""
视频类型
• mp4  –  video/mp4 
• m4v  –  video/x-m4v 
• mkv  –  video/x-matroska 
• webm  –  video/webm 
• mov  –  video/quicktime 
• avi  –  video/x-msvideo 
• wmv  –  video/x-ms-wmv 
• mpg  –  video/mpeg 
• flv  –  video/x-flv
"""
def AddVideo(username,password,video,database,dir_path):
    video_src= dir_path+video
    try:
        files = {'file': (video, open( video_src, 'rb' ), {'Expires': '0'})}
    except:
        return {"state":404,"message":"no find video"}
    request_url = "http://api.stargatedb.com:8002/addvideo?username="+username+"&password="+password+"&database=" + str(database)
    response = requests.post( request_url,files = files)
    result_str = response.text
    return eval(result_str)

def DeleteVideo(username,password,video,database):
    request_url = "http://api.stargatedb.com:8002/deletevideo?username="+username+"&password="+password+"video=" + str( video ) + "&database=" + str(database)
    headers = {'content-type': 'application/x-www-form-urlencoded'}
    response = requests.post( request_url, headers=headers )
    result_str = response.text
    return eval(result_str)

def FindVideo(username,password,video,database,save_dir):
    request_url = "http://api.stargatedb.com:8002/findvideo?username="+username+"&password="+password+"&database=" + str( database ) + "&video=" + str( video )
    headers = {'content-type': 'application/x-www-form-urlencoded'}
    response = requests.post( request_url, headers=headers )
    result_str = response.text
    if not os.path.exists( save_dir ):
        os.mkdir( save_dir )
    video_path=save_dir+"/"+video
    try:
        result_str=eval( result_str )
        if result_str['state'] == 415:
            return {"state": 415, "message": "Unsupported video type"}
        if result_str['state']==404:
            return result_str
    except:
        with open(video_path,'wb') as f:
            f.write(response.content)
        return {"state":200,"message":"find video success"}

#----附件存储
"""
附件类型
• epub  –  application/epub+zip
• zip  –  application/zip
• tar  –  application/x-tar
• rar  –  application/x-rar-compressed
• gz  –  application/gzip 
• bz2  –  application/x-bzip2 
• 7z  –  application/x-7z-compressed 
• xz  –  application/x-xz 
• pdf  –  application/pdf 
• exe  –  application/x-msdownload 
• swf  –  application/x-shockwave-flash 
• rtf  –  application/rtf 
• eot  –  application/octet-stream 
• ps  –  application/postscript 
• sqlite  –  application/x-sqlite3 
• nes  –  application/x-nintendo-nes-rom 
• crx  –  application/x-google-chrome-extension 
• cab  –  application/vnd.ms-cab-compressed 
• deb  –  application/x-deb 
• ar  –  application/x-unix-archive 
• Z  –  application/x-compress 
• lz  –  application/x-lzip
"""
def AddResour(username,password,resour,database,dir_path):
    resour_src= dir_path+resour
    try:
        files = {'file': (resour, open( resour_src, 'rb' ), {'Expires': '0'})}
    except:
        return {"state":404,"message":"no find resour"}
    request_url = "http://api.stargatedb.com:8002/addresour?username="+username+"&password="+password+"&database=" + str(database)
    response = requests.post( request_url,files = files)
    result_str = response.text
    return eval(result_str)

def DeleteResour(username,password,resour,database):
    request_url = "http://api.stargatedb.com:8002/deleteresour?username="+username+"&password="+password+"&resour=" + str( resour ) + "&database=" + str(database)
    headers = {'content-type': 'application/x-www-form-urlencoded'}
    response = requests.post( request_url, headers=headers )
    result_str = response.text
    return eval(result_str)

def FindResour(username,password,resour,database,save_dir):
    request_url = "http://api.stargatedb.com:8002/findresour?username="+username+"&password="+password+"&database=" + str( database ) + "&resour=" + str( resour )
    headers = {'content-type': 'application/x-www-form-urlencoded'}
    response = requests.post( request_url, headers=headers )
    result_str = response.text
    if not os.path.exists( save_dir ):
        os.mkdir( save_dir )
    video_path=save_dir+"/"+resour
    try:
        result_str=eval( result_str )
        if result_str['state'] == 415:
            return {"state": 415, "message": "Unsupported resour type"}
        if result_str['state']==404:
            return result_str
    except:
        with open(video_path,'wb') as f:
            f.write(response.content)
        return {"state":200,"message":"find resour success"}

#-----示列代码-----
# res=AddAudio("xxxxx","xxxxx","1.mp3","new","./new/")
# print(res)

# res=FindAudio("xxxxx","xxxxx","1.mp3","new","./test/")
# print(res)

# res=DeleteAudio("xxxxx","xxxxx","1.mp3","new")
# print(res)

# res=Add("wumeng","xxxxx","xxxxx","无梦","new",30)
# print(res)

# res=Change("xxxxx","xxxxx","new",10)
# print(res)

# res=Delete("xxxxx","xxxxx")
# print(res)

# res=AllFind("xxxxx","xxxxx","new")
# for i in res:
#     print(res[i]['value'])



#!/usr/bin/env python
# -*- coding:utf-8
from .libs import pyredis as pyredis
_redis=pyredis.PyRedis()

def Set(name, value,ex=None, px=None, nx=False, xx=False, keepttl=False):
    _redis.Set(name, value,ex, px, nx, xx, keepttl)

def Get(name):
    return _redis.Get(name)

def Delete(name):
    return _redis.Delete(name)

def Close():
    return _redis.Close()

def Client():
    _redis.Client()


#!/usr/bin/env python
# -*- coding:utf-8

import cv2
class Opencv():
    #----找图
    def OpencvFindPicture(self, target, template):
        _target = cv2.imread( target )
        _template = cv2.imread( template )
        theight, twidth = template.shape[:2]
        result = cv2.matchTemplate( _target, _template, cv2.TM_SQDIFF_NORMED )
        cv2.normalize( result, result, 0, 1, cv2.NORM_MINMAX, -1 )
        min_val, max_val, min_loc, max_loc = cv2.minMaxLoc( result )
        # strmin_val = str( min_val )
        cv2.rectangle( _target, min_loc, (min_loc[0] + twidth, min_loc[1] + theight), (0, 0, 225), 2 )
        x = min_loc[0]
        y = min_loc[1]
        return x, y



import setuptools
setuptools.setup(
    name="stargatedb", # Replace with your own username
    version="1.0.2",
    author="yangpai",
    author_email="wumeng@mail.yangpai.co",
    description="stargatedb is a microcomputer database developed by Chongqing Yangpai Information Technology Co., Ltd., which supports Chinese and English characters and multimedia data storage. It is mainly used in Internet of things, robot, intelligent hardware, industrial automation and other fields",
    long_description="stargatedb is a microcomputer database developed by Chongqing Yangpai Information Technology Co., Ltd., which supports Chinese and English characters and multimedia data storage. It is mainly used in Internet of things, robot, intelligent hardware, industrial automation and other fields",
    long_description_content_type="text/markdown",
    url="http://www.stargatedb.com",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=2.7'
)



#!/usr/bin/env python
# -*- coding:utf-8
from .libs import autogui,common,ai,opencv
_opencv=opencv.Opencv()
_autogui=autogui.Autogui()
_ai=ai.Ai()
_common=common

def ImgCompress(in_dir, out_dir,width,high,num=1):
    _common.ImgCompress(in_dir,out_dir,width,high,num)

def Synthesis(image):
    return _ai.ImageSynthesis(image)

def FindPicture(target,template):
    return _opencv.OpencvFindPicture(target,template)

def ImageCapture(x=None, y=None, x1=None, y1=None,image="ImageCapture.bmp" ,mod=1,t1=0,t2=0):
    return _common.CommonImageCapture(x, y, x1, y1,image ,mod,t1,t2)

def WordsCapture(x=None, y=None, x1=None, y1=None,image="WordsCapture.bmp" ,mod=1,t1=0,t2=0):
    return _common.CommonWordsCapture(x, y, x1, y1,image ,mod,t1,t2)